@@ -15,11 +15,15 @@ SAtree = function(tree, complete = TRUE) {
 }
 
 #' Transforms a tree and fossils dataframe to a combined SA tree.
+#' 
 #' Sampled ancestors are represented as tips on zero-length edges to maintain compatibility with the ape format.
-#' Tip labels are set to "species id"_"index", where the most recent tip of a given species receives index 1 and indices increase towards the past.
+#' Tip labels are set to "species id"_"index". The order of the indexes is given by `tip_order`: either the oldest tip of a given species 
+#' receives index 1 and indexes increase towards the present (default) or the reverse.
 #'
 #' @param tree Phylo object.
 #' @param fossils Fossils object.
+#' @param tip_order Order of indexes to assign to the tips, either `oldest_first` (by default, indexes increase towards the present) or `youngest_first` 
+#' (indexes increase towards the past).
 #' @return A list of `tree`, the SA tree integrating the fossils, and `fossils`, the fossils object updated with the tip label of each sample.
 #' @examples
 #' # simulate tree
@@ -32,9 +36,11 @@ SAtree = function(tree, complete = TRUE) {
 #' t2 = SAtree.from.fossils(t,f)
 #' plot(t2$tree)
 #' @export
-SAtree.from.fossils = function(tree, fossils) {
+SAtree.from.fossils = function(tree, fossils, tip_order = c("oldest_first", "youngest_first")) {
   if(!is.fossils(fossils)) stop("Argument fossils must be a valid fossils object")
   
+  if(length(tip_order) > 1) tip_order = tip_order[1]
+  
   if(length(fossils[,1])==0) {
     tree$tip.label = paste0(tree$tip.label, "_", 1)
     return(list(tree = SAtree(tree, TRUE), fossils = fossils))
@@ -58,6 +64,7 @@ SAtree.from.fossils = function(tree, fossils) {
   }
   
   #renaming all species not in fossils
+  extant_tips = tree$tip.label
   for(i in 1:ntips) {
     if(!i %in% fossils$sp) {
       tree$tip.label[i] = paste0(tree$tip.label[i], "_", 1)
@@ -70,6 +77,10 @@ SAtree.from.fossils = function(tree, fossils) {
     if(fossils$sp[i] !=  current_spec) {
       if(current_spec <= ntips) tree$tip.label[current_spec] = paste0(tree$tip.label[current_spec], "_", count_spec)
       current_spec = fossils$sp[i]
+      if(current_spec > ntips) { #avoiding duplicates with existing tip labels
+        edge_label = paste0("t", current_spec)
+        while(edge_label %in% extant_tips) edge_label = paste0(edge_label, "b")
+      }
       count_spec = 1
     }
     #adding new speciation node
@@ -86,7 +97,7 @@ SAtree.from.fossils = function(tree, fossils) {
     tree$edge = rbind(tree$edge,c(totalnodes,-i))
     tree$edge.length = c(tree$edge.length,0)
     if(current_spec <= ntips) tree$tip.label = c(tree$tip.label, paste0(tree$tip.label[current_spec], "_", count_spec))
-    else tree$tip.label = c(tree$tip.label, paste0("t", current_spec, "_", count_spec))
+    else tree$tip.label = c(tree$tip.label, paste0(edge_label, "_", count_spec))
     fossils$tip.label[i] = tree$tip.label[length(tree$tip.label)]
     count_spec = count_spec +1
   }
@@ -114,6 +125,23 @@ SAtree.from.fossils = function(tree, fossils) {
     tree$edge[which(tree$edge==-i)] = ntips + i
   }
   
+  if(tip_order == "youngest_first") {
+    new_labels = tree$tip.label
+    split_tip_labels = strsplit(tree$tip.label, split = "_", fixed = T)
+    sp_labels = sapply(split_tip_labels, function(t) t[1])
+    idxs = sapply(split_tip_labels, function(t) t[2])
+    
+    for(sp in unique(sp_labels)) {
+      sp_positions = which(sp_labels == sp)
+      sp_idxes = as.numeric(idxs[sp_positions])
+      sp_idxes = max(sp_idxes) + 1 - sp_idxes
+      new_labels[sp_positions] = paste0(sp, "_", sp_idxes)
+    }
+    names(new_labels) = tree$tip.label
+    fossils$tip.label = new_labels[fossils$tip.label]
+    tree$tip.label = new_labels
+  }
+  
   #force reordering for nice plotting
   attr(tree,"order")=NULL
   tree = ape::reorder.phylo(tree)
